CoolProp Windows Installer
==========================

[InnoSetup][] script to install some of the CoolProp wrappers for Windows and 
to activate the add-in for Microsoft Excel.

It is based on a fork of the [ExcelAddinInstaller][] by [Daniel Kraus][] and 
you should have a look at the original [documentation][README_original.md] for 
more details and [licensing terms][LICENSE]. The [vanilla] branch contains an 
unmodified version of the upstream repository to simplify the integration of 
changes in the original code. 

Included Wrappers
-----------------

As of September 2016, this script only contains the Excel add-in, but more 
wrappers might be included as optional installs later.


[InnoSetup]: http://www.jrsoftware.org/isinfo.php
[Daniel Kraus]: http://github.com/bovender
[ExcelAddinInstaller]: https://github.com/bovender/ExcelAddinInstaller
[vanilla]: https://github.com/CoolProp/ExcelAddinInstaller/tree/vanilla